@@ -1,10 +1,10 @@
-__version__ = "0.1.9"
+__version__ = "0.2"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.1.9)'
+__git_branch__ = '(detached from v0.2)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'df0bc44629f37867538dae7f07469f6b4b9f39ea'
-__git_head_subject__ = 'update homepage'
+__git_head_hash__ = '0987104c1268efc4726d870e404bf609b245d248'
+__git_head_subject__ = 'Finished release v0.2.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
