@@ -15,14 +15,20 @@ class Configuration(Model):
         from json import load
         filepath = filepath or CONFIGFILE_PATH
         with open(filepath) as fd:
-            return cls(**load(fd))
+            data = load(fd)
+        self = cls()
+        for key, value in data.iteritems():
+            setattr(self, key, value)
+        return self
 
     def save(self, filepath=None):
         from json import dump
         filepath = filepath or CONFIGFILE_PATH
+        serialize = getattr(self, "to_python") if hasattr(self, "to_python") else getattr(self, "serialize")
         with open(filepath, 'w') as fd:
-            dump(self.to_python(), fd, indent=4)
+            dump(serialize(), fd, indent=4)
 
     def to_json(self, indent=False):
         from json import dumps
-        return dumps(self.to_python(), indent=indent)
+        serialize = getattr(self, "to_python") if hasattr(self, "to_python") else getattr(self, "serialize")
+        return dumps(serialize(), indent=indent)
